#!/bin/bash

# + ============================================================== +
#  Copyright (c) 2022, Intel Corporation.

#  This source code and any documentation accompanying it ("Material") is 
#  furnished under license and may only be used or copied in accordance with
#  the terms of that license.  No license, express or implied, by estoppel
#  or otherwise, to any intellectual property rights is granted to you by 
#  disclosure or delivery of these Materials.  The Materials are subject to
#  change without notice and should not be construed as a commitment by 
#  Intel Corporation to market, license, sell or support any product or 
#  technology.  Unless otherwise provided for in the license under which
#  this Material is provided, the Material is provided AS IS, with no
#  warranties of any kind, express or implied, including without limitation
#  the implied warranties of fitness, merchantability, or non-infringement.
#  Except as expressly permitted by the license for the Material, neither 
#  Intel Corporation nor its suppliers assumes any responsibility for any 
#  errors or inaccuracies that may appear herein.  Except as expressly
#  permitted by the license for the Material, no part of the Material may be
#  reproduced, stored in a retrieval system, transmitted in any form, or
#  distributed by any means without the express written consent of 
#  Intel Corporation.

# + ============================================================== +

if [ $(id -u) -ne 0 ]; then
    echo -e "\e[31mRun as root user OR with sudo\e[0m"
    exit 1
fi

function clean_from_config() {
    ip=$1
    echo "============= $ip ============="
    echo "Clearing mount processes"
    proc=/usr/local/SDPTool/.proc/$ip/pid
    if [ -f $proc ]; then 
        pids=$(cat $proc | awk -F':::' '{print $3}')
        p=($pids)
        echo "Found ${#p[@]} active entries"
        if [ ! -z "$pids" ]; then
            echo "Exiting active processes"
            kill -9 $pids > /dev/null 2>&1
            sleep 10
        fi
        echo "Cleaning config file"
        rm -f $proc
    else
        echo "Vmedia config is clean"
    fi
    echo "****************************************"
    echo
}

function cls_proc_from_ip() {
    ip=$1
    pids=$(ps -elf | grep $ip | grep -e "VMViewer\|VMCLI" | awk '{print $4}')
    if [ ! -z "$pids" ]; then
        echo "============= $ip ============="
        echo "Cleaning Stale Processes"
        kill -9 $pids > /dev/null 2>&1
        echo "****************************************"
        echo
    fi
}

function cls_all_proc() {
    ips=$(ls /usr/local/SDPTool/.proc/)
    for ip in $ips; do
        clean_from_config $ip
        cls_proc_from_ip $ip
    done
}


if [ -z $1 ]; then
    echo -e "\e[31mCaution: This will terminate all BMC virtual media mounted by SDPTool\e[0m"
    while [[ $reply != "Y" && $reply != "y" && $reply != "N" && $reply != "n" ]]; do
        echo "Do you Agree to proceed? (Y/N)"
    	read reply
    done

    if [[ $reply = "N" || $reply = "n" ]]; then
	    exit
    fi

    cls_all_proc
else
    clean_from_config $1
    cls_proc_from_ip $1
fi
